﻿using System;
using System.Collections.Generic;
using System.Linq;
using RH.WikiNavigation.DataClasses;
using System.Web.UI;

namespace RH.WikiNavigation
{
    public static class Extensions
    {
        internal static IEnumerable<WikiData> Traverse(this IEnumerable<WikiData> source, Func<WikiData, IEnumerable<WikiData>> fnRecurse)
        {
            foreach (WikiData item in source)
            {
                yield return item;

                IEnumerable<WikiData> seqRecurse = fnRecurse(item);
                if (seqRecurse == null) continue;

                foreach (WikiData itemRecurse in Traverse(seqRecurse, fnRecurse))
                    yield return itemRecurse;
            }
        }

        internal static bool ContainsLink(this WikiData data, string link)
        {
            if (data == null) throw new ArgumentNullException("data");
            
            // check root (itself and direct children)
            if (link.EndsWith("/" + data.FileName)) return true;
            if (data.Links.Contains(link)) return true;

            // check elementes beneath
            return data.Children.Traverse(x => x.Children).Any(l => l.Links.Contains(link));
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="page"></param>
        /// <param name="queryString"></param>
        /// <returns>value for queryString as ToUpper() string</returns>
        internal static string GetQueryString(this Page page, string queryString)
        {
            return page.Request[queryString] == null ? null : page.Request[queryString].ToUpper();
        }
    }
}